import request from '@/plugins/request'

export default {
  namespaced: true,
  state() {
    return {
      userInfo: uni.getStorageSync('userInfo') || {},
      code: uni.getStorageSync('code') || '',
      uid: uni.getStorageSync('uid') || '',
      accessToken: uni.getStorageSync('accessToken') || '',
      openId: uni.getStorageSync('openId') || '',
    }
  },
  mutations: {
    setUserInfo(state, data) {
      uni.setStorageSync('userInfo', data)
      state.userInfo = data
    },
    setCode(state, data) {
      uni.setStorageSync('code', data)
      state.code = data
    },
    setUid(state, data) {
      uni.setStorageSync('uid', data)
      state.uid = data
    },
    setAccessToken(state, data) {
      uni.setStorageSync('accessToken', data)
      state.accessToken = data
    },
    setOpenId(state, data) {
      uni.setStorageSync('openId', data)
      state.openId = data
    },
  },
  actions: {
    uniLogin({ commit }) {
      return new Promise((resolve, reject) => {
        uni.login({
          success(res) {
            commit('setCode', res.code)
            resolve()
          },
          fail() {
            commit('setCode', '')
            uni.showToast({
              title: '获取code失败，请稍后重试',
              icon: 'none',
            })
            reject()
          },
        })
      })
    },
    login({ commit }, { code, encryptedData, iv }) {
      return new Promise(async (resolve, reject) => {
        const appId = uni.getAccountInfoSync().miniProgram.appId
        try {
          const res = await request.post(
            `/mini/wx/user/${appId}/getToken`,
            {
              code,
              encryptedData,
              iv,
            },
            {
              clearCode: true,
            },
          )
          const { uid, accessToken, openId } = res
          commit('setUid', uid)
          commit('setAccessToken', accessToken)
          commit('setOpenId', openId)
          resolve()
        } catch (e) {
          reject(e)
        }
      })
    },
    getOpenId({ commit }) {
      uni.login({
        async success(res) {
          const appId = uni.getAccountInfoSync().miniProgram.appId
          try {
            const result = await request.get(`/mini/wx/user/${appId}/login?code=${res.code}`)
            const { openid } = result
            commit('setOpenId', openid)
            commit('setCode', '')
          } catch (e) {}
        },
        fail(e) {
          console.log(e, '<<<<<<<<获取code失败原因')
          commit('setCode', '')
        },
      })
    },
  },
}
